#include "headers.ih"

Headers::Headers()
:
    FBB::MailHeaders(cin)
{
    fillXheaders();
}
